/*------------------------------------------------------------------------------
 *
 * Calculate_Ref_Index() - Called from Menu_G() -
 *                         1. Calls Report_Error() if the input data will result
 *                            in a zero denominator or negative square root.
 *                         2. Calculates the value fo Alpha, Beta, Gamma, or
 *                            N depending on the value of Gchoice.
 *                         3. When the calculation is complete, the values of
 *                            all variables are diplayed to the screen.  The
 *                            display is stopped from scrolling to allow the
 *                            user to read the results - the return key must be
 *                            pressed to continue.
 *
 *------------------------------------------------------------------------------
 */

#include "opt_cal.h"
Calculate__Ref_Index(Alpha,Beta,Gamma,N,Theta_x,Theta_y,Theta_z,Gchoice)
double Alpha;                  /* principle refractive index           */
double Beta;                   /* principle refractive index           */
double Gamma;                  /* principle refractive index           */
double N;                      /* random refractive index              */
double Theta_x;                /* angle between N and x-axis           */
double Theta_y;                /* angle between N and y-axis           */
double Theta_z;                /* angle between N and z-axis           */
char Gchoice;                  /* determines variable to be solved for */
{
  char x;                      /* dummy scanning variable              */
  int ErrorFlag = 0;
  double Radian = 57.29577951; /* conversion from degrees to radians   */
  double Temp1;                /* temporary variable                   */

  extern double sqr();
  extern Report_Error();
  switch(Gchoice)
  {
    case '1' : Temp1 = 1/sqr(N) -
                       sqr(cos(Theta_y/Radian)) / sqr(Beta) -
                       sqr(cos(Theta_z/Radian)) / sqr(Gamma);

               if(Temp1 <= 0)
                 {
                   Report_Error(25);
                   ErrorFlag = 1;
                 }

               else Alpha = sqrt( sqr(cos(Theta_x/Radian)) /
                                  Temp1
                                );
               break;

    case '2' : Temp1 = 1/sqr(N) -
                       sqr(cos(Theta_x/Radian)) / sqr(Alpha) -
                       sqr(cos(Theta_z/Radian)) / sqr(Gamma);

               if(Temp1 <= 0)
                 {
                   Report_Error(26);
                   ErrorFlag = 1;
                 }

               else Beta = sqrt( sqr(cos(Theta_y/Radian)) /
                                 Temp1
                               );
               break;

    case '3' : Temp1 = 1/sqr(N) -
                       sqr(cos(Theta_x/Radian)) / sqr(Alpha) -
                       sqr(cos(Theta_y/Radian)) / sqr(Beta);

               if(Temp1 <= 0)
                 {
                   Report_Error(27);
                   ErrorFlag = 1;
                 }

               else Gamma = sqrt( sqr(cos(Theta_z/Radian)) /
                                  Temp1
                                );
               break;

    case '4' : N = 1/sqrt(
                           sqr(cos(Theta_x/Radian))/sqr(Alpha) +
                           sqr(cos(Theta_y/Radian))/sqr(Beta)  +
                           sqr(cos(Theta_z/Radian))/sqr(Gamma)
                         );
               break;

  }/*END SWITCH*/

  if(ErrorFlag != 1)
   {
     printf("\n\tAlpha   = %.4f\n", Alpha);
     printf("\tBeta    = %.4f\n", Beta);
     printf("\tGamma   = %.4f\n", Gamma);
     printf("\tn       = %.4f\n", N);
     printf("\n\tTheta_x = %.2f\n",Theta_x);
     printf("\tTheta_y = %.2f\n",Theta_y);
     printf("\tTheta_z = %.2f\n",Theta_z);
     fflush(stdin);
     printf("\nPress 'Return' to continue\n\n");
     scanf("%c", &x);
   }
}/*END Calculate_Ref_Index*/
/*-----------------------------------------------------------------------------*/
