/*------------------------------------------------------------------------------
 *
 * Menu_A() - Called from main() - Diplays the menu for performing Alpha, Beta,
 *            Gamma, and 2Vx calculations and scans for user input.  Depending
 *            on user input Menu_A() will:
 *
 *            1.  Prompt the user and scan for the three remaining variables via
 *                the switch-case statement.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_ABG2V() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_A()
{
  char Achoice;               /* Menu choice scanning variable    */
  char Ascan[20];													/* floating point scanning variable */
  int  MenuFlag;              /* Menu selection flag              */

  double Alpha;               /* smallest refractive index     */
  double Beta;                /* intermediate refractive index */
  double Gamma;               /* largest refractive index      */
  double Two_Vx;              /* two V of minerals             */
  double Two_Vz;              /*  == 180 - Two_Vx              */

  extern double Test_Inputs();
  extern Report_Error();
  extern Calculate_ABG2V();

  do
  {
    Two_Vx = Two_Vz = MenuFlag = 2;
    Alpha = 1.01;
    Gamma = 2.99;
		
		  printf("\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu A:  Alpha, Beta, Gamma, & 2V Calculations\n\n");
		  printf("\tWhich would you like to calculate?\n\n");
		  printf("\t(1) Alpha.\n\n");
		  printf("\t(2) Beta.\n\n");
		  printf("\t(3) Gamma.\n\n");
		  printf("\t(4) 2Vx.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Achoice);
		  fflush(stdin);
		
		  switch(Achoice)
		  {
		    case '1' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Beta  (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Beta = Test_Inputs(Ascan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Gamma (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Gamma = Test_Inputs(Ascan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter 2Vx   (nnn.nn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Two_Vx = Test_Inputs(Ascan)) == HUGE_VAL );
                 break;

		    case '2' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Alpha (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Alpha = Test_Inputs(Ascan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Gamma (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Gamma = Test_Inputs(Ascan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter 2Vx   (nnn.nn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Two_Vx = Test_Inputs(Ascan)) == HUGE_VAL );
		               Beta = (Alpha + Gamma)/2;
                 break;

		    case '3' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Alpha (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Alpha = Test_Inputs(Ascan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Beta  (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Beta = Test_Inputs(Ascan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter 2Vx   (nnn.nn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Two_Vx = Test_Inputs(Ascan)) == HUGE_VAL );
                 break;

		    case '4' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Alpha (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Alpha = Test_Inputs(Ascan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Beta  (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Beta = Test_Inputs(Ascan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Gamma (n.nnnn) -> ");
		                scanf("%20s", &Ascan);
		               }while( (Gamma = Test_Inputs(Ascan)) == HUGE_VAL );
                 break;

		    case 'q' :
		    case 'Q' : MenuFlag = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag = 0;
		               break;
		  }/*END SWITCH*/

    Two_Vz = 180 - Two_Vx;

    if( Alpha  <=   1 || Alpha  >=   3 || Beta   <=   1   || Beta   >=   3 ||
        Gamma  <=   1 || Gamma  >=   3 || Two_Vx <=   0   || Two_Vx >= 180 ||
        Two_Vz <=   0 || Two_Vz >= 180 || Alpha  >= Beta  || Beta >= Gamma  )
      Report_Error(4);

    else if(MenuFlag != 0) Calculate_ABG2V(Alpha,Beta,Gamma,Two_Vx,Achoice);

 } while(Achoice != 'q' && Achoice != 'Q');

}/*END Menu_A*/
/*-----------------------------------------------------------------------------*/
