/*------------------------------------------------------------------------------
 *
 * Menu_G() - Called from main() - Diplays the menu for performing Random
 *            Refractive Index (Alpha, Beta, Gamma, or n) calculations and scans
 *            for user input.  Depending on user input Menu_G() will:
 *
 *            1.  Prompt the user and scan for the three remaining variables via
 *                the switch-case statement. In addition the user will also be
 *                prompted to enter the x,y,and z angles of the random
 *                refractive index.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Ref_Index() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_G()
{
  char Gchoice;               /* Menu choice scanning variable    */
  char Gscan[20];													/* floating point scanning variable */
  int  MenuFlag;              /* Menu selection flag              */

  double Alpha;               /* principle refractive index */
  double Beta;                /* principle refractive index */
  double Gamma;               /* principle refractive index */
  double N;                   /* random refractive index    */

  double Theta_x;             /* angle between N and x-axis */
  double Theta_y;             /* angle between N and y-axis */
  double Theta_z;             /* angle between N and z-axis */

  double Temp1;                 /* temporary variable                */
  double Radian = 57.29577951;  /* conversion for degrees to radians */

  extern double sqr();
  extern Report_Error();
  extern double Test_Inputs();
  extern Calculate_Ref_Index();

  do
  {
    Alpha = 1.5;
    Beta = N = MenuFlag = 2;
    Gamma = 2.5;
    Theta_x = Theta_y = Theta_z = 54.73;
		  printf("\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu G:  Random Refractive Index Calculations\n\n");
		  printf("\tWhich would you like to calculate?\n\n");
		  printf("\t(1) Alpha.\n\n");
		  printf("\t(2) Beta.\n\n");
		  printf("\t(3) Gamma.\n\n");
		  printf("\t(4) n.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Gchoice);
		  fflush(stdin);
		
		  switch(Gchoice)
		  {
		    case '1' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Beta    (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Beta = Test_Inputs(Gscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Gamma   (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Gamma = Test_Inputs(Gscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter n       (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (N = Test_Inputs(Gscan)) == HUGE_VAL );
                 Alpha = 1.00001;
                 break;

		    case '2' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Alpha   (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Alpha = Test_Inputs(Gscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Gamma   (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Gamma = Test_Inputs(Gscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter n       (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (N = Test_Inputs(Gscan)) == HUGE_VAL );
		               Beta = (Alpha + Gamma)/2;
                 break;

		    case '3' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Alpha   (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Alpha = Test_Inputs(Gscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Beta    (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Beta = Test_Inputs(Gscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter n       (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (N = Test_Inputs(Gscan)) == HUGE_VAL );
		               Gamma = 2.999999;
                 break;

		    case '4' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter Alpha   (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Alpha = Test_Inputs(Gscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Beta    (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Beta = Test_Inputs(Gscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Gamma   (n.nnnn) -> ");
		                scanf("%20s", &Gscan);
		               }while( (Gamma = Test_Inputs(Gscan)) == HUGE_VAL );
		               N = (Alpha + Gamma)/2;
                 break;

		    case 'q' :
		    case 'Q' : MenuFlag = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag = 0;
		               break;
		  }/*END SWITCH*/

    if(MenuFlag != 0)
     {
		     do
		     {
		      fflush(stdin);
		      printf("\n\tEnter Theta_x (nnn.nn) -> ");
		      scanf("%20s", &Gscan);
		     }while( (Theta_x = Test_Inputs(Gscan)) == HUGE_VAL );
		     do
		     {
		      fflush(stdin);
		      printf("\tEnter Theta_y (nnn.nn) -> ");
		      scanf("%20s", &Gscan);
		     }while( (Theta_y = Test_Inputs(Gscan)) == HUGE_VAL );

		     do
		     {
		      fflush(stdin);
		      printf("\tEnter Theta_z (nnn.nn) -> ");
		      scanf("%20s", &Gscan);
		     }while( (Theta_z = Test_Inputs(Gscan)) == HUGE_VAL );
     }/*End if*/

    Temp1 = sqr(cos(Theta_x/Radian)) +
            sqr(cos(Theta_y/Radian)) +
            sqr(cos(Theta_z/Radian));

    if( Alpha   <=  1    || Alpha   >=  3     || Beta    <=  1     ||
        Beta    >=  3    || Gamma   <=  1     || Gamma   >=  3     ||
        N       <=  1    || N       >=  3     || Gamma   <   N     ||
        Gamma   <   Beta || N       <   Alpha || Beta    <   Alpha ||
        Theta_x <   0    || Theta_x >  90     || Theta_y <   0     ||
        Theta_y >  90    || Theta_z <   0     || Theta_z >  90     ||
        fabs(Temp1 - 1) > 0.001  )
      Report_Error(24);

    else if(MenuFlag != 0)
      Calculate__Ref_Index(Alpha,Beta,Gamma,N,Theta_x,Theta_y,Theta_z,Gchoice);
 } while(Gchoice != 'q' && Gchoice != 'Q');

}/*END Menu_G*/
/*-----------------------------------------------------------------------------*/
