/*------------------------------------------------------------------------------
 *
 * Menu_H() - Called from main() - Diplays the menu for performing Kamb's
 *            Method and scans for user input.  Depending on user input
 *            Menu_H() will:
 *
 *            1.  Prompt the user for Kamb's Method input data.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Kamb() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_H()
{
  char Hchoice;          /* Menu choice scanning variable    */
  char Hscan[20];								/* floating point scanning variable */
  int  MenuFlag;         /* Menu selection flag              */

  double NA;             /* numerical aperture of microscope lens         */
  double Beta;           /* approximate beta refractive index of material */
  double SR;             /* microscope stage rotation                     */

  extern Report_Error();
  extern Calculate_Kamb();
  extern double Test_Inputs();
  do
  {
    NA = 0.5;
    Beta = SR = MenuFlag = 2;

		  printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu H:  Kamb's Method.\n\n");
		  printf("\tWhich would you like?\n\n");
		  printf("\t(1) Enter Kamb's Method data.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Hchoice);
		  fflush(stdin);
		
		  switch(Hchoice)
		  {
		    case '1' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter NA     (0.nn) -> ");
		                scanf("%20s", &Hscan);
		               }while( (NA = Test_Inputs(Hscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter Beta (n.nnnn) -> ");
		                scanf("%20s", &Hscan);
		               }while( (Beta = Test_Inputs(Hscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter SR     (nn.n) -> ");
		                scanf("%20s", &Hscan);
		               }while( (SR = Test_Inputs(Hscan)) == HUGE_VAL );
                 break;

		    case 'q' :
		    case 'Q' : MenuFlag = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag = 0;
		               break;
		  }/*END SWITCH*/

    if( NA   <=  0.2 || NA   >=  0.9 || Beta <=  1.2 ||
        Beta >=  3.0 || SR   <   1.0 || SR   >  46.0 )
      Report_Error(28);

    else if(MenuFlag != 0) Calculate_Kamb(NA,Beta,SR);
 } while(Hchoice != 'q' && Hchoice != 'Q');

}/*END Menu_H*/
/*-----------------------------------------------------------------------------*/
