/*------------------------------------------------------------------------------
 *
 * Menu_I() - Called from main() - Diplays the menu for performing Stereographic
 *            calculations and scans for user input.  Depending on user input
 *            Menu_I() will:
 *
 *            1.  Prompt the user for unit vector input data.
 *                 a) For each value that is entered, Test_Inputs() is called
 *                    to ensure that it is a valid number.
 *                 b) Report_Error() is called to report an out of range
 *                    condition if any of the entered numbers fail the range
 *                    checking for this equation.
 *                 c) Calculate_Stereograhic() is called to perform the required
 *                    computation if all numerical values are good.
 *            2.  Call Report_Error() for invalid menu selection.
 *            3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_I()
{
  char Ichoice;          /* Menu choice scanning variable    */
  char Iscan[20];								/* floating point scanning variable */
  int  MenuFlag;         /* Menu selection flag              */

  double phi1;           /* spherical coordinates of unit vector 1 */
  double rho1;

  double phi2;											/* spherical coordinates of unit vector 2 */
  double rho2;

  extern Report_Error();
  extern double Test_Inputs();
  extern Calculate_Stereographic();

  do
  {
    phi1 = rho1 = phi2 = rho2 = MenuFlag = 1;
		  printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
		  printf("\tMenu I:  Stereographic Calculations.\n\n");
		  printf("\tWhich would you like?\n\n");
		  printf("\t(1) Enter spherical unit vector data.\n\n");
		  printf("\t(Q) Return to Main Menu.\n\n");
		  printf("\tEnter Selection and press 'Return':  ");
		
		  fflush(stdin);
		  scanf("%1c", &Ichoice);
		  fflush(stdin);
		
		  switch(Ichoice)
		  {
		    case '1' : do
		               {
		                fflush(stdin);
		                printf("\n\tEnter phi1 (nnn.n) -> ");
		                scanf("%20s", &Iscan);
		               }while( (phi1 = Test_Inputs(Iscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter rho1 (nnn.n) -> ");
		                scanf("%20s", &Iscan);
		               }while( (rho1 = Test_Inputs(Iscan)) == HUGE_VAL );
		
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter phi2 (nnn.n) -> ");
		                scanf("%20s", &Iscan);
		               }while( (phi2 = Test_Inputs(Iscan)) == HUGE_VAL );
		               do
		               {
		                fflush(stdin);
		                printf("\tEnter rho2 (nnn.n) -> ");
		                scanf("%20s", &Iscan);
		               }while( (rho2 = Test_Inputs(Iscan)) == HUGE_VAL );
                 break;

		    case 'q' :
		    case 'Q' : MenuFlag = 0;
		               printf("\n\nReturn to Main Menu.\n\n\n");
		               break;
		
		    default  : Report_Error(1);
		               MenuFlag = 0;
		               break;
		  }/*END SWITCH*/

    if( phi1 < -360 || phi1 >  360 || rho1 <    0 ||
        rho1 >   90 || phi2 < -360 || phi2 >  360 ||
        rho2 <    0 || rho2 >   90 )
      Report_Error(30);

    else if(MenuFlag != 0) Calculate_Stereographic(phi1,rho1,phi2,rho2);

 } while(Ichoice != 'q' && Ichoice != 'Q');

}/*END Menu_I*/
/*-----------------------------------------------------------------------------*/
