/*------------------------------------------------------------------------------
 *
 * Menu_Snell() - Called from main() - Diplays the menu for Snell's Law (to
 *                calculate "ni", "nt", "theta i", and "theta t") and scans for
 *                user input.  Depending on user input Menu_Snell() will:
 *
 *                1.  Prompt the user and scan for the three remaining variables
 *                    via the switch-case statement.
 *                     a) For each value that is entered, Test_Inputs() is
 *                        called to ensure that it is a valid number.
 *                     b) Report_Error() is called to report an out of range
 *                        condition if any of the entered numbers fail the
 *                        range checking for this equation.
 *                     c) Calculate_Snell() is called to perform the required
 *                        computation if all numerical values are good.
 *                2.  Call Report_Error() for invalid menu selection.
 *                3.  Exit and return to the main menu.
 *
 *------------------------------------------------------------------------------
 */
#include "opt_cal.h"
Menu_Snell()
{
  char SNchoice;       /* Menu choice scanning variable    */
  char SNscan[20];					/* floating point scanning variable */
  int  MenuFlag;       /* Menu selection flag              */

  double N_incd;       /* refractive index of incident material     */
  double N_tran;       /* refractive index of transmitting material */
  double Theta_incd;   /* angle of incidence                        */
  double Theta_tran;   /* angle of transmittance (or refraction)    */

  extern Report_Error();
  extern Calculate_Snell();
  extern double Test_Inputs();
  do
  {
    N_incd = N_tran = Theta_incd = Theta_tran = MenuFlag = 1;

    printf("\n\n\n\n\n\n\n\n\n\n\n\n");
				printf("\tSnell's Law: Which would you like to calculate?\n\n");
				printf("\t(1) ni.\n\n");
				printf("\t(2) nt.\n\n");
				printf("\t(3) theta i.\n\n");
				printf("\t(4) theta t.\n\n");
				printf("\t(Q) Return to Menu D.\n\n");
				printf("\tEnter Selection and press 'Return':  ");
															
				fflush(stdin);
				scanf("%1c", &SNchoice);
				fflush(stdin);
															
				switch(SNchoice)
				{
				  case '1': do
											     {
											      fflush(stdin);
											      printf("\n\tEnter nt      (n.nnnn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (N_tran = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter Theta i (nnn.nn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (Theta_incd = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter Theta t (nnn.nn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (Theta_tran = Test_Inputs(SNscan)) == HUGE_VAL );
							         break;
						case '2': do
											     {
											      fflush(stdin);
											      printf("\n\tEnter ni      (n.nnnn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (N_incd = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter Theta i (nnn.nn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (Theta_incd = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter Theta t (nnn.nn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (Theta_tran = Test_Inputs(SNscan)) == HUGE_VAL );
                break;
						case '3': do
											     {
											      fflush(stdin);
											      printf("\n\tEnter ni      (n.nnnn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (N_incd = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter nt      (n.nnnn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (N_tran = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter Theta t (nnn.nn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (Theta_tran = Test_Inputs(SNscan)) == HUGE_VAL );
                break;
						case '4': do
											     {
											      fflush(stdin);
											      printf("\n\tEnter ni      (n.nnnn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (N_incd = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter nt      (n.nnnn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (N_tran = Test_Inputs(SNscan)) == HUGE_VAL );
													   do
											     {
											      fflush(stdin);
											      printf("\tEnter Theta i (nnn.nn) -> ");
											      scanf("%20s", &SNscan);
											     }while( (Theta_incd = Test_Inputs(SNscan)) == HUGE_VAL );
                break;
						case 'q':
						case 'Q': MenuFlag = 0;
														  printf("\n\nReturn to Menu D.\n\n\n");
														  break;
														
						default : Report_Error(1);
														  MenuFlag = 0;
														  break;
				}/*END SWITCH*/
															
			 if( N_incd     <=  1.0 || N_incd     >=  3.0 || N_tran     <=  1.0 ||
				    N_tran     >=  3.0 || Theta_incd <  0.0  || Theta_incd > 90.0  ||
				    Theta_tran <  0.0  || Theta_tran > 90.0 )
				  Report_Error(7);
				
				else if( MenuFlag != 0 )
				Calculate_Snell(N_incd,N_tran,Theta_incd,Theta_tran,SNchoice);
  } while(SNchoice != 'q' && SNchoice != 'Q');

}/*END Menu_Snell*/
/*-----------------------------------------------------------------------------*/
